/*
 * Copyright (C) 2000-2006 by ETH Zurich
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ETH ZURICH AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ETH ZURICH
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.btnode.ethz.ch
 *
 */

/**
 * \file _con_mgr.h
 * 
 * \author Kevin Martin <kevmarti@tik.ee.ethz.ch> 
 * 
 * \date 2006/03/23
 * 
 * \brief Interface to develop connection managers.
 * 
 * Write your own implementation of a connection manager against the interface
 * defined in this file: write implementations of the functions defined
 * here, and register them at the connection manager stack during
 * initialization.
 * 
 * \see #cm_tree.h
 * \see #cm_tree.c
 * 
 * as an example.
 */
#ifndef _CON_MGR_H
#define _CON_MGR_H

#include <bt/bt_defs.h>
#include <bt/bt_psm.h>

/**
 * \brief Registers terminal commands of the connection manager.
 * Call this function if you need the debug and control commands of the 
 * connection manager.
 */
#define CM_REGISTER_CMDS \
	void (*cm_reg_cmds) (void)

/**
 * \brief Disables BT inquiries.
 * Blocks if an inquiry is already in progress.
 */
#define CM_INQ_DISABLE \
	void (*cm_inq_disable) (void)

/**
 * \brief Reenables BT inquiries.
 */
#define CM_INQ_ENABLE \
	void (*cm_inq_enable) (void)

/*
 * \brief Writes connection information to the buffer passed
 */
#define CM_FILL_CON_INFO \
	short (*cm_fill_con_info) (u_char* args, u_char* param)

/*
 * \brief Returns an array with reliable connection handles
 */
#define CM_GET_REL_CONS \
	u_char (*cm_get_rel_cons)(bt_hci_con_handle_t *rel_cons)	

/**
 * \brief Definition of the connection manager stack.
 */
typedef struct con_mgr_stack_s {
	CM_REGISTER_CMDS;
	CM_INQ_DISABLE;
	CM_INQ_ENABLE;
	CM_FILL_CON_INFO;
	CM_GET_REL_CONS;
	HCI_CON_TABLE_CB;			///< con table change callback
	void* con_table_cb_arg;		///< con table change callback argument
} con_mgr_stack_t;

/**
 * \brief The connection manager stack.
 */
con_mgr_stack_t con_mgr_stack;

#endif
