/*
 * Copyright (C) 2000-2004 by ETH Zurich
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ETH ZURICH AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ETH ZURICH
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.btnode.ethz.ch/
 *
 *
 */

 /**
 * boot_defs.h
 *
 * 2004.02.19 Martin Hinz <hinz@tik.ee.ethz.ch>
 * 2004.10.14 Matthias Ringwald <mringwal@inf.ethz.ch>
 * 2005.05.18 Mustafa Yuecel <yuecelm@ee.ethz.ch>
 *
 */

#ifndef _SUPPORT_BOOTLOADER_H_
#define _SUPPORT_BOOTLOADER_H_


/* -------------------------------------------------------------------------
 *  Defines
 * ------------------------------------------------------------------------- */

#define T_DATA          0       //data record
#define T_EOF           1       //end of file
#define T_ESA           2       //extended segment address
#define T_ELA           4       //extended linear address

#define XBANK_PRSTART    0      //start of bootloader data in external ram banks
#define XBANK_PREND      0x2CCFFUL

#define FLASH_PREND      0x1DFFFUL // last possible address for program in flash

#define REPROG_BTNODE_PROGRAM_DATA 0
#define REPROG_TARGET_PROGRAM_DATA 1
#define REPROG_DATA_ACTIVE 170
#define REPROG_BOOT_ACTIVE 85

#define PAGE_SIZE 256

#define NOPAGE          1       //not a valid page address

/*
 * error codes: if an error occures the error code will be displayed (leds) for
 * not more than 2 seconds and btnode will reboot.
 */
#define ERR_NON         0       //no error occured
#define ERR_CODE        1       //invalid code at loc 0x00000
#define ERR_DATA        2       //no btnode program data
#define ERR_CRC_HEADER  4       //header crc wrong
#define ERR_CRC_DATA    5       //data crc wrong
#define ERR_INACTIVE    6       //data is not active
#define ERR_UART        7       //uart programming error
#define ERR_PROG_LEN    8       //prog_len is zero
#define ERR_MEMADDR     9       //bad memory address, would overwrite bootloader

#define ERR_TEST        2



/* ------------------------------------------------------------------------------
 * | prog_type | prog_ver | active_flag | prog_len | CRC |   ...data...    | CRC |
 * ------------------------------------------------------------------------------
 *       1           4           1            4       2     ..[prog_len]..    2
 * program data records are of the format LLLAAADDDDDDD....
 *
 * where LLL  is the record lenght in bytes
 *       AAA  the starting address
 *       D    program data (L times)
 *
 * program data is expected to start at address XRAM_PRSTART+MEM_LEN_HEADER+MEM_CRC
 *
 */

#define MEM_LEN_PROG_TYPE 1
#define MEM_OFFSET_PROG_TYPE 0
#define MEM_LEN_PROG_VER 4
#define MEM_OFFSET_PROG_VER 1
#define MEM_LEN_AKTIV_FLAG 1
#define MEM_OFFSET_AKTIV_FLAG 5
#define MEM_LEN_PROG_LEN 4
#define MEM_OFFSET_PROG_LEN 6

#define MEM_CRC CRC_LENGTH
#define MEM_LEN_HEADER MEM_LEN_PROG_TYPE+MEM_LEN_PROG_VER+MEM_LEN_AKTIV_FLAG+MEM_LEN_PROG_LEN

#define TO_ARRAY32(arr, pos, value) arr[pos]=(u_char)((value >> 24)& 0xFF);arr[1+pos]=(u_char)((value >> 16)& 0xFF);arr[2+pos]=(u_char)((value >> 8)& 0xFF);arr[3+pos]=(u_char)(value & 0xFF)

#define FROM_ARRAY32(arr, pos) ((u_long)arr[pos]<<24)|((u_long)arr[1+pos]<<16)|((u_long)arr[2+pos]<<8)|((u_long)arr[3+pos])


#endif
