/*
 * Copyright (C) 2000-2006 by ETH Zurich
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ETH ZURICH AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ETH ZURICH
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.btnode.ethz.ch
 *
 */

/**
 * \file log-cmds.h
 * 
 * \author Kevin Martin <kevmarti@tik.ee.ethz.ch> 
 * 
 * \date 2006/03/23
 * 
 * \brief Terminal commands for accessing the event logger.
 * 
 * The following commands are available
 * - "log show [<nr_msgs> [<class> [<mask>]]]":\n
 * Prints the 'nr_msgs' latest log messages of the class specified,
 * using the log mask given. Pass 0 to print all messages / classes.\n
 * Note that the log mask has to be given in hex-format.
 * 
 * - "log clear": clears the log buffer
 * 
 * - "log logmask <class> [<mask>]":\n
 * Sets the logmask of the specified class to the log mask given.\n
 * Prints out the logmask of the specified class if no log mask is given.
 * 
 * - "log verbosity <class> [<mask>]":\n
 * Sets the log verbosity of the class
 * specified to the log mask given: if set, log messages matching the class
 * and log level(s) specified are printed directely to the terminal after
 * occurence of the triggering event.\n
 * Prints out the verbosity mask of the specified class if no mask is given.
 * 
 * \see #logging.h for further details
 */

#ifndef _LOGCMDS_H_
#define _LOGCMDS_H_

#include <stdio.h>

/**
 * \brief Initializes logging commands.
 * 
 * \param uart Pointer to the terminal uart to use.
 */
void log_cmds_init( FILE *uart);

#endif //_LOGCMDS_H_
