#ifndef _SRTD_LIST_H_
#define _SRTD_LIST_H_

typedef struct sorted_list {
    u_char* nr_elems;
    u_char max_elems;
    void** elems;
    void* data;
    signed char (*elem_cmp)(void*, void*);
    void (*elem_init)(void*, void*, u_char);
    void (*elem_set)(void*, void*, u_char);
    u_char (*is_elem) (void*, void*, u_char);
} srtd_list_t;

/* Initializes a sorted list, given a pointer to an array of pointer (each
 * pointer represents an element of the list), the size of the list, the
 * max nr of elements the list should be able to handle, and the amount of
 * space that has to be allocated to store the value of a single element.
 */
srtd_list_t* srtd_list_init(u_char* nr_elems, u_char max_elems, u_long elem_size);

/* Registers the callbacks needed by the sorted list.
 */
void srtd_list_register_cbs(srtd_list_t* list, \
			    signed char (*elem_cmp)(void*, void*), \
			    void (*elem_init)(void*, void*, u_char), \
			    void (*elem_set)(void*, void*, u_char), \
			    u_char (*is_elem) (void*, void*, u_char));
    
/* Adds an element to the sorted list passed. Position is determined by calling
 * the 'elem_cmp' callback provided by the 'cm_sorted_list' struct
 */
short srtd_list_add(srtd_list_t* list, void* args, u_char arg_len);

/* Returns the index of an elem in the list.
 */
short srtd_list_index_of(srtd_list_t* list, void* args, u_char arg_len);

/* Removes the element at position 'index' from the sorted list passed, and
 * adjusts the order accordingly
 */
u_char srtd_list_remove(srtd_list_t* list, u_char index);

/* Replaces the element at position 'index' with the element passed. Afterwards,
 * the element added will be moved to the correct place (according to its
 * value - correct place will be determined by calling the 'elem_cmp' callback)
 */
short srtd_list_set(srtd_list_t* list, u_char index, void* args, u_char args_len);

/* Clears the sorted list
 */
void srtd_list_clear(srtd_list_t* list);

#endif
